/*

Copyright (C) 2000  Paul Wilkins

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
/* lcd.h  by Paul Wilkins 3/21/97 */

#ifndef __LCD_H
#define __LCD_H

#include <gtk/gtk.h>

/* display area in characters */
extern int lcdWidth;
extern int lcdHeight;

GtkWidget *setupLCD(GtkWidget *, int, int, char *);
void redrawLCD();
void clearLCD();

void setLCDDispMode(int);
int getLCDDispMode();


#endif

